@@ -247,19 +247,19 @@ class ToolTreeBuilder(object):
     def refresh(self):
         """Refesh the view to use the latest tool definitions."""
         # Build the data model and update the view to use it.
-        model = QtGui.QStandardItemModel()
+        self.model = QtGui.QStandardItemModel()
         groups = {}
         stores = [acc.tools() for acc in self._accessories.base_items()]
         for store in stores:
             for entry in store.root():
-                self._add_tool_entry(entry, model, groups)
+                self._add_tool_entry(entry, self.model, groups)
         # Remember how many base entries were created
-        self._base_entry_count = model.rowCount()
+        self._base_entry_count = self.model.rowCount()
         if self._accessories.hat:
             store = self._accessories.hat.tools()
             for entry in store.root():
-                self._add_tool_entry(entry, model, groups)
-        self._tree.setModel(model)
+                self._add_tool_entry(entry, self.model, groups)
+        self._tree.setModel(self.model)
 
     def _add_tool_entry(self, entry, group, groups):
         if isinstance(entry, tools.Tool):
@@ -471,7 +471,7 @@ class ToolBoxBuilder(object):
         :return: a QToolBox object.
         """
         self._ui = QtGui.QToolBox()
-        self._top_level_items = self._create_group("", self._ui)
+        self._top_level_items = {}
         self._top_level_count = 0
         self.refresh()
         return self._ui
@@ -484,7 +484,8 @@ class ToolBoxBuilder(object):
         """Refesh the view to use the latest tool definitions."""
         toolbox = self._ui
         _empty_toolbox(toolbox)
-        self._top_level_items.clear()
+        if self._top_level_items:
+            self._top_level_items.clear()
         default_group_icon = kinds.icon_for_kind(kinds.TOOLS_EXT)
         groups = {}
         stores = [acc.tools() for acc in self._accessories.base_items()]
@@ -505,6 +506,8 @@ class ToolBoxBuilder(object):
     def _add_tool_entry(self, entry, group, groups, default_group_icon):
         if isinstance(entry, tools.Tool):
             if isinstance(group, QtGui.QToolBox):
+                if not self._top_level_items:
+                    self._top_level_items = self._create_group("",self._ui)
                 group = self._top_level_items
                 self._top_level_count += 1
             def open_callback():
