@@ -40,6 +40,7 @@ from bzrlib.plugins.explorer.lib import (
     location as mod_location,
     location_set_browser,
     location_viewer,
+    script_engine,
     switch_dialog,
     tool_dialogs,
     ui_explorer,
@@ -118,7 +119,7 @@ def split_command_options(command):
 class QExplorerMainWindow(QBzrWindow):
 
     def __init__(self, parent=None, location_list=None, hat=None,
-            desktop=None, dry_run=False):
+            desktop=None, dry_run=False, _script=None):
         """Create a main window.
 
         :param location: path/URL to location to open or None.
@@ -130,6 +131,7 @@ class QExplorerMainWindow(QBzrWindow):
           If None, an intelligent guess is made.
         :param dry_run: if True, just show commands that will be
           run without running them.
+        :param _script: ID of an internal script to run. Do not use.
         """
         # Init the UI
         QBzrWindow.__init__(self, [], parent)
@@ -220,6 +222,9 @@ class QExplorerMainWindow(QBzrWindow):
                 self.open_saved_location(location)
         else:
             self.do_welcome()
+        if _script:
+            engine = script_engine.ScriptEngine()
+            engine.run(_script, self)
 
     def _refresh_user_configuration(self):
         """Call this after editing bazaar.conf."""
